Description Usage Arguments Functions
This is constructor to make a metabase_handle object which
is used in subsequent functions to interact with the API.
The handle should not be created manually, but should be created
using metabase_login.
1 2 3 | metabase_handle(base_url, database_id, username)
is_metabase_handle(handle)
|
base_url |
Base URL for the Metabase API |
database_id |
Database ID to connect to |
username |
Username |
is_metabase_handle: Check for metabase_handle
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.