metabase_login: Login to Metabase

Description Usage Arguments Details

View source: R/metabaser.R

Description

This will login to the Metabase API with the given username and password. Credentials must be specified either directly through the username and password parameters or as a file through the creds_file parameter.

Usage

1
2
3
4
5
6
7
metabase_login(
  base_url = NULL,
  database_id = NULL,
  creds_file = NULL,
  username = NULL,
  password = NULL
)

Arguments

base_url

Base URL for the Metabase API

database_id

Database ID to connect to

creds_file

File containing Metabase account credentials to connect with

username

Username

password

Password

Details

If used, the creds_file should have "username=username" on one line and "password=password" on the next. If the login is successful, a metabase_handle object will be returned to use in subsequent functions.


PHACDataHub/metabaserer documentation built on March 14, 2021, 12:02 a.m.