metabase_query: Query Metabase

Description Usage Arguments Value

View source: R/metabaser.R

Description

Sends an SQL query to Metabase for the given database. Data is limited to 1 million records by the server using this approach. This might be faster for small lookups of the DB.

Usage

1
metabase_query(handle, sql_query, col_types = NULL)

Arguments

handle

metabase_handle object

sql_query

SQL query to execute

col_types

Column types to use for parsing as specified in read_csv

Value

data.frame containing the results of the query


PHACDataHub/metabaserer documentation built on March 14, 2021, 12:02 a.m.