typically the user will set all values at once from the function metabase_set_defaults
1 | metabase_set_default(param, value)
|
param |
normally one of base_url, database_id, creds_file, username, password |
value |
the value for which ever one is being set |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.