Description Usage Arguments Details
This will login to the Metabase API with the given username and password.
Credentials must be specified either directly through the username and password parameters
or as a file through the creds_file parameter.
1 2 3 4 5 6 7 |
base_url |
Base URL for the Metabase API |
database_id |
Database ID to connect to |
creds_file |
File containing Metabase account credentials to connect with |
username |
Username |
password |
Password |
If used, the creds_file should have "username=username" on one line and "password=password" on the next.
If the login is successful, a metabase_handle object will be returned to use in subsequent functions.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.