Description Usage Arguments Value
Sends an SQL query to Metabase for the given database. Data is limited to 1 million records by the server using this approach. This might be faster for small lookups of the DB.
1 | metabase_query(handle, sql_query, col_types = NULL)
|
handle |
metabase_handle object |
sql_query |
SQL query to execute |
col_types |
Column types to use for parsing as specified in |
data.frame containing the results of the query
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.