Description Usage Arguments Value
Sends an SQL query to Metabase for the given database. Data is limited to 2000 records by the server using this approach. This might be faster for small lookups of the DB.
1 2 3 4 5 6 7 | metabase_query_sql(
sql_query,
handle = metabase_login_default(),
col_types = readr::cols(.default = readr::col_character()),
use_cache = TRUE,
...
)
|
sql_query |
SQL query to execute |
handle |
metabase_handle object |
col_types |
default column type can be set to character for all |
use_cache |
if TRUE will use the cache if it is available |
data.frame containing the results of the query
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.